@@ -2,9 +2,10 @@ from . import util
 from . import log
 from . import ocr_youdao
 from . import ocr_baidu
+from .yaml_boot import YamlBoot, BreakException
 
 __author__ = "shigebeyond"
-__version__ = "1.0.3"
+__version__ = "1.0.5"
 __description__ = "pyutilb: python common util code"
 
 __all__ = [
@@ -15,4 +16,6 @@ __all__ = [
     "log",
     "ocr_youdao",
     "ocr_baidu",
+    "YamlBoot",
+    "BreakException"
 ]
\ No newline at end of file
